==> carbon-component-mapper-3.11.4.tgz: package/esm/date-picker/date-picker.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import React from 'react';
import PropTypes from 'prop-types';
import useFieldApi from "@data-driven-forms/react-form-renderer/use-field-api";
import CarbonDatePicker from "carbon-components-react/es/components/DatePicker/DatePicker.js";
import DatePickerInput from "carbon-components-react/es/components/DatePickerInput/DatePickerInput.js";
import prepareProps from '../prepare-props';
import HelperTextBlock from '../helper-text-block/helper-text-block';

var DatePicker = function DatePicker(props) {
  var _useFieldApi = useFieldApi(prepareProps(props)),
      input = _useFieldApi.input,
      datePickerType = _useFieldApi.datePickerType,
      meta = _useFieldApi.meta,
      DatePickerProps = _useFieldApi.DatePickerProps,
      validateOnMount = _useFieldApi.validateOnMount,
      helperText = _useFieldApi.helperText,
      WrapperProps = _useFieldApi.WrapperProps,
      rest = _objectWithoutProperties(_useFieldApi, ["input", "datePickerType", "meta", "DatePickerProps", "validateOnMount", "helperText", "WrapperProps"]);

  var invalid = (meta.touched || validateOnMount) && (meta.error || meta.submitError);
  var warnText = (meta.touched || validateOnMount) && meta.warning;
  return /*#__PURE__*/React.createElement("div", WrapperProps, /*#__PURE__*/React.createElement(CarbonDatePicker, _extends({}, input, {
    datePickerType: datePickerType
  }, DatePickerProps), /*#__PURE__*/React.createElement(DatePickerInput, _extends({
    id: input.name,
    invalid: Boolean(invalid),
    invalidText: invalid ? invalid : ''
  }, rest))), /*#__PURE__*/React.createElement(HelperTextBlock, {
    helperText: !invalid && helperText,
    warnText: warnText
  }));
};

DatePicker.propTypes = {
  isDisabled: PropTypes.bool,
  isRequired: PropTypes.bool,
  datePickerType: PropTypes.string,
  DatePickerProps: PropTypes.object,
  WrapperProps: PropTypes.object
};
DatePicker.defaultProps = {
  datePickerType: 'single'
};
export default DatePicker;

==> carbon-component-mapper-3.17.0.tgz: package/esm/date-picker/date-picker.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["input", "datePickerType", "meta", "DatePickerProps", "validateOnMount", "helperText", "WrapperProps"];
import React from 'react';
import PropTypes from 'prop-types';
import useFieldApi from "@data-driven-forms/react-form-renderer/use-field-api";
import CarbonDatePicker from "carbon-components-react/es/components/DatePicker/DatePicker.js";
import DatePickerInput from "carbon-components-react/es/components/DatePickerInput/DatePickerInput.js";
import prepareProps from '../prepare-props';
import HelperTextBlock from '../helper-text-block/helper-text-block';

var DatePicker = function DatePicker(props) {
  var _useFieldApi = useFieldApi(prepareProps(props)),
      input = _useFieldApi.input,
      datePickerType = _useFieldApi.datePickerType,
      meta = _useFieldApi.meta,
      DatePickerProps = _useFieldApi.DatePickerProps,
      validateOnMount = _useFieldApi.validateOnMount,
      helperText = _useFieldApi.helperText,
      WrapperProps = _useFieldApi.WrapperProps,
      rest = _objectWithoutProperties(_useFieldApi, _excluded);

  var invalid = (meta.touched || validateOnMount) && (meta.error || meta.submitError);
  var warnText = (meta.touched || validateOnMount) && meta.warning;
  return /*#__PURE__*/React.createElement("div", WrapperProps, /*#__PURE__*/React.createElement(CarbonDatePicker, _extends({}, input, {
    datePickerType: datePickerType
  }, DatePickerProps), /*#__PURE__*/React.createElement(DatePickerInput, _extends({
    id: input.name,
    invalid: Boolean(invalid),
    invalidText: invalid ? invalid : ''
  }, rest))), /*#__PURE__*/React.createElement(HelperTextBlock, {
    helperText: !invalid && helperText,
    warnText: warnText
  }));
};

DatePicker.propTypes = {
  isDisabled: PropTypes.bool,
  isRequired: PropTypes.bool,
  datePickerType: PropTypes.string,
  DatePickerProps: PropTypes.object,
  WrapperProps: PropTypes.object
};
DatePicker.defaultProps = {
  datePickerType: 'single'
};
export default DatePicker;
